#!/usr/bin/env python3

import vtk
import sys

def gen_shot(vtk_filename, png_filename):
    reader = vtk.vtkPLYReader()
    reader.SetFileName(vtk_filename)
    reader.Update()

    gf = vtk.vtkGraphicsFactory()
    gf.SetOffScreenOnlyMode(1)
    gf.SetUseMesaClasses(1)

    tr = vtk.vtkTransform()
    tr.RotateWXYZ(45,1,1,1)

    trans = vtk.vtkTransformPolyDataFilter()
    trans.SetInputData(reader.GetOutput())
    trans.SetTransform(tr)
    trans.Update()

    mapper = vtk.vtkPolyDataMapper()
    mapper.SetInputData(trans.GetOutput())
    #mapper.SetScalarModeToUseCellData()

    actor = vtk.vtkActor()
    actor.SetMapper(mapper)
    actor.SetScale(1)
    actor.GetProperty().BackfaceCullingOn()

    mapper2 = vtk.vtkPolyDataMapper()
    mapper2.SetInputData(trans.GetOutput())
    actor2 = vtk.vtkActor()
    actor2.SetMapper(mapper2)
    actor2.GetProperty().SetRepresentationToWireframe()

    #camera = vtk.vtkCamera()
    #camera.SetPosition(538.289, 991.653, 3752.77)
    #camera.SetFocalPoint(538.289, 991.653, 188.469)
    #camera.SetViewAngle(30)
    #camera.SetClippingRange(2676.99, 4689.85)

    ren = vtk.vtkRenderer()
    ren.SetBackground(0.9, 0.9, 0.9)
    renWin = vtk.vtkRenderWindow()
    renWin.SetOffScreenRendering(1)
    renWin.SetSize(1600, 1600)
    renWin.AddRenderer(ren)
    ren.AddActor(actor)
    ren.AddActor(actor2)
    # call render to setup the default camera with the right properties
    renWin.Render()
    # then only change the view angle
    camera = ren.GetActiveCamera()
    camera.SetViewAngle(18)
    ren.SetActiveCamera(camera)
    # and render again with the new view angle
    renWin.Render()

    image = vtk.vtkWindowToImageFilter()
    image.SetInput(renWin)
    #image.SetMagnification(3)
    image.SetInputBufferTypeToRGBA()
    image.Update()

    writer = vtk.vtkPNGWriter()
    writer.SetFileName(png_filename)
    writer.SetInputConnection(image.GetOutputPort())
    writer.Write()

if __name__ == "__main__":
    gen_shot(sys.argv[1], sys.argv[2])
